| Title: | ERS RMarkdown Template and Functions to Read, Write, Validate, and Visualize Data |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Zach Friedman [aut, cre], Tommy Bellaire [aut] (ORCID: <https://orcid.org/0009-0006-1075-3155>) |
| Maintainer: | Zach Friedman <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.1.2 |
| Built: | 2026-06-04 06:49:19 UTC |
| Source: | https://github.com/ERStrategies/erstools |
This function applies skimr::skim() to summarize a dataset and then formats numeric columns.
Numeric values are rounded to one decimal place. If a number is 1,000 or greater, it is formatted with commas.
ers_column_info(dataset)ers_column_info(dataset)
dataset |
A data frame or tibble to be summarized. |
A tibble with summary statistics, where numeric values are rounded to one decimal place and large numbers (≥ 1,000) are formatted with commas.
This function loads a set of commonly used libraries, categorizes them, suppresses unnecessary startup messages, and prints a summary of successfully loaded libraries. If any packages are missing, a warning is displayed at the bottom.
ers_load_packages()ers_load_packages()
A categorized summary of loaded libraries and a warning message for missing packages.
ers_load_packages()ers_load_packages()
Read files from sharepoint with clean names
ers_read_clean( folder_path, file_name_with_extension, sheet_name = NULL, drive_name = "client_work_drive", skip_rows = 0, na_values = c(""), clean_names = TRUE )ers_read_clean( folder_path, file_name_with_extension, sheet_name = NULL, drive_name = "client_work_drive", skip_rows = 0, na_values = c(""), clean_names = TRUE )
folder_path |
REQUIRED: The path to the file: https://app.tettra.co/teams/ersknowledge/pages/copying-a-folder-path-from-sharepoint-to-use-in-r |
file_name_with_extension |
REQUIRED: Supported extensions: .csv, .xls, .xlsx. Example: "student_performance.csv" |
sheet_name |
OPTIONAL: Only required if you have an excel spreadsheet with multiple sheets. Example: "Sheet 2" |
drive_name |
OPTIONAL: R will detect what drive the file is from (e.g. 'client_work_drive', 'internal_drive', 'external_drive', or 'data_hub_drive') |
skip_rows |
OPTIONAL: Only required if your data doesn't start in the first row of the spreadsheet. Example: If your data starts in row 4 then enter 3 |
na_values |
OPTIONAL: By default will change all cells to NA if they have "", "N/A", "NA", or "Missing" |
clean_names |
OPTIONAL: standardizes column names by removing special characters, converting to snake_case, and ensuring uniqueness |
Your loaded data as a data frame with the name raw_data
Output your data as a nicely formatted table using the gt package
ers_table(dataset, title = "Default Title")ers_table(dataset, title = "Default Title")
dataset |
REQUIRED: The data that you want to make into a table |
title |
REQUIRED: Desired title of your data table. Example: "Teacher FTE by School" |
Your data as a nicely formatted table
Create a new ERS R Markdown file from a template
ers_template(file_name, include_walkthrough = FALSE)ers_template(file_name, include_walkthrough = FALSE)
file_name |
The name of the new Rmd file to create (e.g., "my_report"). You do not need to include the .Rmd extension. |
include_walkthrough |
If TRUE or "yes", use the walkthrough template; otherwise, use the standard template |
Creates a new Rmd file in your working directory
Installs or updates the public erstools package from GitHub.
ers_update_erstools()ers_update_erstools()
Invisibly returns TRUE if installation succeeds.